Stan Math Library: stan/math/prim/mat/meta/VectorViewMvt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
VectorViewMvt.hpp File Reference
`#include <stan/math/prim/mat/meta/is_vector_like.hpp>`
`#include <stan/math/prim/scal/meta/is_vector_like.hpp>`
`#include <stan/math/prim/scal/meta/scalar_type_pre.hpp>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::VectorViewMvt< T, is_array, throw_if_accessed >
class | stan::VectorViewMvt< const T, is_array, throw_if_accessed >
| VectorViewMvt that has const correctness. More...

## Namespaces
| stan

[ Stan Home Page ] © 2011–2016, Stan Development Team.